@@ -53,6 +53,8 @@ func NewCmdClone(f *cmdutil.Factory, runF func(*CloneOptions) error) *cobra.Comm
 			git remote called "upstream". The remote name can be configured using %[1]s--upstream-remote-name%[1]s.
 			The %[1]s--upstream-remote-name%[1]s option supports an "@owner" value which will name
 			the remote after the owner of the parent repository.
+
+			If the repository is a fork, its parent repository will be set as the default remote repository.
 		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			opts.Repository = args[0]
@@ -162,7 +164,7 @@ func cloneRun(opts *CloneOptions) error {
 		return err
 	}
 
-	// If the repo is a fork, add the parent as an upstream
+	// If the repo is a fork, add the parent as an upstream remote and set the parent as the default repo.
 	if canonicalRepo.Parent != nil {
 		protocol, err := cfg.GetOrDefault(canonicalRepo.Parent.RepoHost(), "git_protocol")
 		if err != nil {
@@ -178,8 +180,7 @@ func cloneRun(opts *CloneOptions) error {
 		gc := gitClient.Copy()
 		gc.RepoDir = cloneDir
 
-		_, err = gc.AddRemote(ctx, upstreamName, upstreamURL, []string{canonicalRepo.Parent.DefaultBranchRef.Name})
-		if err != nil {
+		if _, err := gc.AddRemote(ctx, upstreamName, upstreamURL, []string{canonicalRepo.Parent.DefaultBranchRef.Name}); err != nil {
 			return err
 		}
 
@@ -190,6 +191,16 @@ func cloneRun(opts *CloneOptions) error {
 		if err := gc.SetRemoteBranches(ctx, upstreamName, `*`); err != nil {
 			return err
 		}
+
+		if err = gc.SetRemoteResolution(ctx, upstreamName, "base"); err != nil {
+			return err
+		}
+
+		connectedToTerminal := opts.IO.IsStdoutTTY()
+		if connectedToTerminal {
+			cs := opts.IO.ColorScheme()
+			fmt.Fprintf(opts.IO.ErrOut, "%s Repository %s set as the default repository. To learn more about the default repository, run: gh repo set-default --help\n", cs.WarningIcon(), cs.Bold(ghrepo.FullName(canonicalRepo.Parent)))
+		}
 	}
 	return nil
 }
